pub fn bipolar_grounded_extension<A>(
framework: &BipolarFramework<A>,
) -> Result<HashSet<A>, Error>Expand description
The bipolar grounded extension.
The Dung grounded extension is unique and may or may not be support-closed. If it is not, this function returns the largest support-closed subset of it — specifically, the result of iteratively removing any argument whose direct supporter is missing. (This differs from the preferred/complete case where we drop the whole candidate; grounded is unique so we must always return something.)